The source repository for this project can be found at:

  https://opendev.org/openstack/python-brick-cinderclient-ext

Pull requests submitted through GitHub are not monitored.

To start contributing to OpenStack, follow the steps in the contribution guide
to set up and use Gerrit:

  https://docs.openstack.org/contributors/code-and-documentation/quick-start.html

Bugs should be filed on Launchpad:

  https://bugs.launchpad.net/python-cinderclient

  .. note::
     When creating a bug, please tag it with 'brick-cinderclient-ext'.
     To create a tag, select the 'Extra options' after filling in the
     bug description and type **brick-cinderclient-ext** in the 'Tags'
     text box.

For more specific information about contributing to this repository, see the
python-brick-cinderclient-ext contributor guide:

  https://docs.openstack.org/python-brick-cinderclient-ext/latest/contributor/contributing.html
